/*
 * Copyright (c)2009-2010 app.jbbres.com. All rights reserved.
 *
 * This software is the confidential and proprietary information of 
 * app.jbbres.com. ("Confidential Information"). You shall not 
 * disclose such Confidential Information and shall use it only 
 * in accordance with the terms of the license agreement you entered 
 * into with app.jbbres.com.
 */
package com.jbbres.examples.actions;

import java.awt.Component;
import java.io.File;
import javax.swing.*;
import com.jbbres.lib.actions.elements.*;
import com.jbbres.lib.actions.tools.elements.SimpleAction;
import com.jbbres.lib.actions.workflow.Workflow;

/**
 * This action returns the path or the name of files 
 * passed into it.
 * The Action receive an array of File (File[]) and 
 * return an array of String []
 */
public class GetFileName 
	extends SimpleAction<File[], String[]> {

	// The action UI uses the following 
	//Swing objects 
	JPanel uiPanel = new JPanel();
	JLabel resultLabel = new JLabel("Result:");
	String[] pathTypes = 
		{"Full path", "File name only"};
	JComboBox pathTypeComboBox = 
		new JComboBox(pathTypes);
	
	/**
	 * Instantiates a new action.
	 */
	public GetFileName(Workflow workflow) {
		super(workflow);
		uiPanel.add(resultLabel);
		uiPanel.add(pathTypeComboBox);
	}

	/**
	 * This method is called when the workflow is 
	 * executed. 
	 * @param input - the result of the previous action.
	 */
	public String[] execute(File[] input) 
		throws ActionExecutionException {
		if (input == null)
			return null;
		
		String[] result = new String[input.length];
		
		for (int i = 0; i < input.length; i++){
			if (pathTypeComboBox.getSelectedItem()
					.equals("Full path")){
				result[i] = input[i].getPath();
			} else {
				result[i] = input[i].getName();
			}
		}
		return result;
	}

	/**
	 * The action UI.
	 */
	public Component getUI() {
		return uiPanel;

	}

	/**
	 * Returns the action settings as
	 * a Parameter object.
	 */
	public Parameters getParameters() {
		Parameters parameters = new Parameters();
		parameters.setParameter("result.path.type", 
				(String)pathTypeComboBox.getSelectedItem());
		return parameters;
	}

	/**
	 * Sets the action settings from a
	 * Parameters object.
	 */
	public void setParameters(Parameters parameters)
			throws InvalidParametersException {
		String pathType = 
			parameters.getParameter("result.path.type");
		pathTypeComboBox.setSelectedItem(pathType);		
	}

}
